
---

## `SECURITY.md`

```markdown
# Security Policy

## Supported Versions
We support the latest minor release.

## Reporting a Vulnerability
Please email **bazdalaz@gmail.com** with details and a PoC if possible.
We will acknowledge within 72 hours and work on a fix.
Do not post security vulnerabilities in the issue tracker.
```
